pub fn device_info(device: &CombsDevice) -> DeviceInfoExpand description
Initializes the wgpu runtime for device and returns adapter information.
Note: this performs the cubecl runtime setup for the device (the same setup burn performs lazily on first tensor use), so it is safe to use the device for compute afterwards.